import { ApiCall } from "tsrpc";
import { HuoDongFun } from "../../../public/huodongfun";
import { PlayerFun } from '../../../public/player';
import { ReqBuy, ResBuy } from "../../../shared/protocols/event/zixuanlibao/PtlBuy";

export default async function (call: ApiCall<ReqBuy, ResBuy>) {
    let _hdinfo = await HuoDongFun.getHdidInfo(call, call.req.hdid)
    if (!_hdinfo || Object.keys(_hdinfo).length <= 0) {
        // 无此活动
        return call.error('', { code: -1, message: globalThis.lng.huodong_open_1 })
    }

    let _dbType: `zixuanlibao${number}` = `zixuanlibao${call.req.hdid}`

    let conf = _hdinfo.data.gift[call.req.index];
    if (!conf || conf.payId) return call.errorCode(-1);

    let selectPrize = conf.prize.map((v, i) => v[call.req.prizeIndex[i]]).filter(p => !!p);
    if (selectPrize.length < conf.prize.length) return call.errorCode(-2);

    let buyNum = (await G.mongodb.cEvent(_dbType).findOne({ uid: call.uid, type: _dbType }))?.record?.[call.req.index] || 0;
    if (buyNum >= conf.buyNum) return call.errorCode(-3);

    if (conf.need.length > 0) {
        await PlayerFun.checkNeedIsMeet(call, conf.need);
        await PlayerFun.cutNeed(call, conf.need);
    }

    await PlayerFun.sendPrize(call, selectPrize);

    G.mongodb.cEvent(_dbType).updateOne(
        { uid: call.uid, type: _dbType },
        { $inc: G.mongodb.createTreeObj({ key: `record.${call.req.index}`, val: 1 }) },
        { upsert: true }
    );

    call.succ({
        prize: selectPrize
    });
}